@@ -6,9 +6,11 @@ function(x,xlim,ylim,xlab,ylab,main,...){
 
 		if(missing(main)){main="Observed Score Distribution\n"}
 		
-		if(missing(xlim)){xlim=c(0,max(x$scoresbysubject))}
+		if(missing(xlim)){xlim=c(min(x$scoresbysubject),max(x$scoresbysubject))}
 		
 		if(missing(ylab)){ylab="Density of Score"}
+		xlab <- "Observed Scores"
+		
 		
 
 		ymax<-max(density(x$scoresbysubject,from=0,to=max(x$scoresbysubject))$y)
@@ -16,7 +18,7 @@ function(x,xlim,ylim,xlab,ylab,main,...){
 		if(missing(ylim)){ylim=c(0,ymax+.02)}
 
 
-		plot(c(0,max(x$scoresbysubject)),c(0,ymax),type="n",xlim=xlim, ylim=ylim ,xlab=xlab,ylab=ylab,main = main,...)
+		plot(xlim,ylim,type="n",xlim=xlim, ylim=ylim ,xlab=xlab,ylab=ylab,main = main,...)
 		ngrps<-length(x$groups)
 
 		plot_colors <- c("blue","red","forestgreen","black","yellow","orange")
@@ -34,9 +36,9 @@ function(x,xlim,ylim,xlab,ylab,main,...){
 		
 		}
 
-		legend(0, ymax+.02,x$groups, cex=0.8, col=plot_colors[1:ngrps],lty=line_type[1:ngrps], lwd=2, bty="n");
+		legend(min(x$scoresbysubject), ymax+.02,x$groups, cex=0.8, col=plot_colors[1:ngrps],lty=line_type[1:ngrps], lwd=2, bty="n");
 
-		axis(3,at=x$quantiles, lab=labels(x$quantiles),tck=0)
+		axis(3,at=x$quantiles, labels=labels(x$quantiles),tck=0)
 		abline(v=x$quantiles,col="blue",lty=2)
 		box()
 
