@@ -4,11 +4,13 @@ function(x,xlim,ylim,xlab,ylab,main,...){
 
 
 		if(missing(main)){main="Observed Score Distribution\n"}
-		if(missing(xlab)){xlab="Score"}
+	#	if(missing(xlab)){xlab="Score"}
 		if(missing(xlim)){xlim=c(0,max(x$scoresbysubject))}
 		
 		if(missing(ylab)){ylab="Density of Score"}
-		
+	
+
+		xlab <- "Observed Scores"
 
 		ymax<-max(density(x$scoresbysubject,from=0,to=max(x$scoresbysubject))$y)
 
@@ -17,7 +19,7 @@ function(x,xlim,ylim,xlab,ylab,main,...){
 	
 	plot(density(x$scoresbysubject,from=0,to=max(x$scoresbysubject)),xlim=xlim,ylim=ylim,ylab=ylab,xlab=xlab,main = main,...)
 
-		axis(3,at=x$quantiles, lab=labels(x$quantiles),tck=0)
+		axis(3,at=x$quantiles, labels =labels(x$quantiles),tck=0)
 		abline(v=x$quantiles,col="blue",lty=2)
 		box()
 
