@@ -7,15 +7,13 @@ function(OBJ, axis, quants, main, xlim, ylim, xlab, ylab, ...){
 		if(missing(ylim)){ylim=c(min(OBJ$scoresbysubject),max(OBJ$scoresbysubject))}
 		if(missing(xlim)){xlim=c(min(axis),max(axis))}	
 
-
-	evals<-apply(OBJ$probs[,-c(1:3)],2,function(x)sum(x*OBJ$probs[,3]))
 	
-	plot(axis,evals,type="l",ylab=ylab,xlab=xlab,xlim=xlim,ylim=ylim,main=main,...)
+	plot(axis,OBJ$expectedscores,type="l",ylab=ylab,xlab=xlab,xlim=xlim,ylim=ylim,main=main,...)
 
 	
-		axis(3,at=quants, lab=labels(quants),tck=0)
-		abline(v=quants,col="blue",lty=2)
+	axis(3,at=quants, lab=labels(quants),tck=0)
+	abline(v=quants,col="blue",lty=2)
 	
-	return(round(evals,3))
+	return(round(OBJ$expectedscores,3))
 }
 
